@@ -2,7 +2,7 @@
 (*                                                                        *)
 (*  This file is part of Calendar.                                        *)
 (*                                                                        *)
-(*  Copyright (C) 2003-2010 Julien Signoles                               *)
+(*  Copyright (C) 2003-2009 Julien Signoles                               *)
 (*                                                                        *)
 (*  you can redistribute it and/or modify it under the terms of the GNU   *)
 (*  Lesser General Public License version 2.1 as published by the         *)
@@ -20,10 +20,12 @@
 (*  LICENSE.                                                              *)
 (**************************************************************************)
 
+(*i $Id: date.ml 225 2009-12-14 10:36:08Z signoles $ i*)
+
 (*S Introduction.
 
   This module implements operations on dates representing by their Julian day.
-  Most of the algorithms implemented in this module come from the FAQ
+  Most of the algorithms implemented in this module come from the FAQ 
   available at~:
   \begin{center}http://www.tondering.dk/claus/calendar.html\end{center} *)
 
@@ -38,7 +40,7 @@ type t = field date
 
 type day = Sun | Mon | Tue | Wed | Thu | Fri | Sat
 
-type month =
+type month = 
     Jan | Feb | Mar | Apr | May | Jun | Jul | Aug | Sep | Oct | Nov | Dec
 
 type year = int
@@ -69,17 +71,17 @@ let hash = Utils.Int.hash
 
 (* Constructors. *)
 
-let lt (d1 : int * int * int) (d2 : int * int * int) =
+let lt (d1 : int * int * int) (d2 : int * int * int) = 
   Pervasives.compare d1 d2 < 0
 
 (* [date_ok] returns [true] is the date belongs to the Julian period;
    [false] otherwise. *)
 let date_ok y m d = lt (-4713, 12, 31) (y, m, d) && lt (y, m, d) (3268, 1, 23)
 
-(* Coerce month to the interval ]-oo; 12].
+(* Coerce month to the interval ]-oo; 12]. 
    Note that the used algorithm of [make] does not require any coercion for
    negative months *)
-let coerce_month y m =
+let coerce_month y m = 
   if m < 0 then
     y, m
 (*       (* the below commented lines coerce [m] inside the interval [1;12]
@@ -90,7 +92,7 @@ let coerce_month y m =
     let pred_m = pred m in
     y + pred_m / 12, pred_m mod 12 + 1
 
-let make y m d =
+let make y m d = 
   let y, m = coerce_month y m in
   if date_ok y m d then
     let a = (14 - m) / 12 in
@@ -102,9 +104,9 @@ let make y m d =
     else if lt (y, m, d) (1582, 10, 5) then
       (* Julian calendar *)
       d + (153 * m' + 2) / 5 + y' * 365 + y' / 4 - 32083
-    else
+    else 
       raise Undefined
-  else
+  else 
     raise Out_of_bounds
 
 let lmake ~year ?(month = 1) ?(day = 1) () = make year month day
@@ -116,17 +118,17 @@ let current_day day gmt_hour =
   let hour = Time_Zone.from_gmt () + gmt_hour in
   (* change the day according to the time zone *)
   if hour < 0 then begin
-    assert (hour > - 13);
+    assert (hour > - 13); 
     day - 1
   end else if hour >= 24 then begin
     assert (hour < 36);
     day + 1
-  end else
+  end else 
     day
 
 let jan_1_1970 = 2440588
 
-let from_unixfloat x =
+let from_unixfloat x = 
   let d = int_of_float (x /. 86400.) + jan_1_1970 in
   current_day d (Unix.gmtime x).Unix.tm_hour
 
@@ -142,11 +144,11 @@ let to_mjd d = d - 2400001
 
 (*S Useful operations. *)
 
-let is_leap_year y =
+let is_leap_year y = 
   if y > 1582 then (* Gregorian calendar *)
     y mod 4 = 0 && (y mod 100 <> 0 || y mod 400 = 0)
   else (* Julian calendar *)
-    if y > (- 45) && y <= (- 8) then
+    if y > (- 45) && y <= (- 8) then 
       (* every year divisible by 3 is a leap year between 45 BC and 9 BC *)
       y mod 3 = 0
     else if y <= (- 45) || y >= 8 then y mod 4 = 0
@@ -159,17 +161,17 @@ let is_gregorian d = d >= 2299161
 
 (*S Getters. *)
 
-(* [a] and [e] are auxiliary functions for [day_of_month], [month]
+(* [a] and [e] are auxiliary functions for [day_of_month], [month] 
    and [year]. *)
 let a d = d + 32044
 
-let e d =
-  let c =
-    if is_julian d then d + 32082
+let e d = 
+  let c =   
+    if is_julian d then d + 32082 
     else let a = a d in a - (((4 * a + 3) / 146097) * 146097) / 4
   in c - (1461 * ((4 * c + 3) / 1461)) / 4
 
-let day_of_month d =
+let day_of_month d = 
   let e = e d in
   let m = (5 * e + 2) / 153 in
   e - (153 * m + 2) / 5 + 1
@@ -178,10 +180,10 @@ let int_month d = let m = (5 * e d + 2) / 153 in m + 3 - 12 * (m / 10)
 
 let month d = month_of_int (int_month d - 1)
 
-let year d =
-  let b, c =
+let year d = 
+  let b, c = 
     if is_julian d then 0, d + 32082
-    else
+    else 
       let a = a d in
       let b = (4 * a + 3) / 146097 in
       b, a - (b * 146097) / 4 in
@@ -208,25 +210,25 @@ let days_in_month d =
     | Feb -> if is_leap_year (year d) then 29 else 28
 
 (* Boolean operation using some getters. *)
-let is_leap_day d =
+let is_leap_day d = 
   is_leap_year (year d) && month d = Feb && day_of_month d = 24
 
 let is_valid_date y m d =
   try
     let t = make y m d in
     year t = y && int_month t = m && day_of_month t = d
-  with Out_of_bounds | Undefined ->
+  with Out_of_bounds | Undefined -> 
     false
 
 (*S Period. *)
 
 module Period = struct
 
-  (* Cannot use an [int] : periods on months and years have not a constant
-     number of days.
+  (* Cannot use an [int] : periods on months and years have not a constant 
+     number of days. 
      For example, if we add a "one year" period [p] to the date 2000-3-12,
-     [p] corresponds to 366 days (because 2000 is a leap year) and the
-     resulting date is 2001-3-12 (yep, one year later). But if we add [p] to
+     [p] corresponds to 366 days (because 2000 is a leap year) and the 
+     resulting date is 2001-3-12 (yep, one year later). But if we add [p] to 
      the date 1999-3-12, [p] corresponds to 365 days and the resulting date is
      2000-3-12 (yep, one year later too). *)
   type +'a period = { m (* month *) : int; d (* day *) : int }
@@ -250,7 +252,7 @@ module Period = struct
   let opp x = { m = - x.m; d = - x.d }
 
   (* exactly equivalent to [Pervasives.compare] but more flexible typing *)
-  let compare x y =
+  let compare x y = 
     let n = Pervasives.compare x.m y.m in
     if n = 0 then Pervasives.compare x.d y.d else n
   let equal x y = compare x y = 0
@@ -268,34 +270,18 @@ end
 
 (*S Arithmetic operations on dates and periods. *)
 
-let add d p =
+let add d p = 
+(*  Format.printf "%d %d %d / %d %d %d@."
+    (year d) (int_month d) (day_of_month d)
+    p.Period.y p.Period.m p.Period.d;*)
   let y,m,day = Period.ymd p in
-  make
-    (year d         + y)
-    (int_month d    + m)
+  make 
+    (year d         + y) 
+    (int_month d    + m) 
     (day_of_month d + day)
 
 let sub x y = { Period.empty with Period.d = x - y }
 
-let precise_sub y x =
-  let rec aux m =
-    if x + 31 * m < y then
-      aux (m + 1)
-    else
-      let y' = add x (Period.month m) in
-      let d = y - y' in
-      if d < 0 then
-	let m = m - 1 in
-	(* don't use [y'] below: [m] changes *)
-	m, d + days_in_month (add x (Period.month m))
-      else if d >= days_in_month y' then
-	aux (m + 1)
-      else
-	m, d
-  in
-  let m, d = aux ((y - x) / 31) in
-  { Period.m = m; d = d }
-
 let rem d p = add d (Period.opp p)
 
 let next d = function
@@ -314,7 +300,7 @@ let prev d = function
 
 let same_calendar y1 y2 =
   let d = y1 - y2 in
-  let aux =
+  let aux = 
     if is_leap_year y1 then true
     else if is_leap_year (y1 - 1) then d mod 6 = 0 || d mod 17 = 0
     else if is_leap_year (y1 - 2) then d mod 11 = 0 || d mod 17 = 0
@@ -346,7 +332,7 @@ let nth_weekday_of_month y m d n =
   let first = make y (int_of_month m + 1) 1 in
   let gap =
     let diff = int_of_day d - int_day_of_week first in
-    if diff >= 0 then diff - 7 else diff
+    if diff >= 0 then diff - 7 else diff 
   in
   first + 7 * n + gap
 
@@ -365,13 +351,13 @@ let epact y =
   if y <= 1582 then julian_epact (* Julian calendar *)
   else (* Gregorian calendar *)
     let c = y / 100 + 1 (* century *) in
-    (* 1900 belongs to the 20th century for this algorithm *)
+    (* 1900 belongs to the 20th century for this algorithm *) 
     abs ((julian_epact - (3 * c) / 4 + (8 * c + 5) / 25 + 8) mod 30)
 
 (* [easter] implements the algorithm of Oudin (1940) *)
-let easter y =
+let easter y = 
   let g = y mod 19 in
-  let i, j =
+  let i, j = 
     if y <= 1582 then (* Julian calendar *)
       let i = (19 * g + 15) mod 30 in
       i, (y + y / 4 + i) mod 7
@@ -401,13 +387,13 @@ let corpus_christi y = easter y + 60
 
 let from_unixtm x =
   let d = (* current day at GMT *)
-    make (x.Unix.tm_year + 1900) (x.Unix.tm_mon + 1) x.Unix.tm_mday
+    make (x.Unix.tm_year + 1900) (x.Unix.tm_mon + 1) x.Unix.tm_mday 
   in
   current_day d x.Unix.tm_hour
 
 let to_unixtm d =
   { Unix.tm_sec = 0; Unix.tm_min = 0; Unix.tm_hour = 0;
-    Unix.tm_mday = day_of_month d;
+    Unix.tm_mday = day_of_month d; 
     Unix.tm_mon = int_month d - 1;
     Unix.tm_year = year d - 1900;
     Unix.tm_wday = int_day_of_week d;
@@ -433,8 +419,8 @@ let int_of_day d = let n = int_of_day d in if n = 0 then 7 else n
 
 let from_business y w d =
   if w < 1 || w > weeks_in_year y then invalid_arg "from_business: bad week";
-  let first =
-    try make y 1 1
+  let first = 
+    try make y 1 1 
     with Out_of_bounds | Undefined -> invalid_arg "from_business: bad date"
   in
   let first_day = int_day_of_week first in
@@ -446,9 +432,9 @@ let from_business y w d =
 
 let int_of_day = int_of_day
 
-let day_of_int n =
-  if n > 0 && n < 7 then day_of_int n
-  else if n = 7 then day_of_int 0
+let day_of_int n = 
+  if n > 0 && n < 7 then day_of_int n 
+  else if n = 7 then day_of_int 0 
   else invalid_arg "Not a day"
 
 let int_of_month m = int_of_month m + 1
